@@ -10,11 +10,12 @@ from ..version import __version__
 from .subparsers import build
 from .subparsers import clean
 from .subparsers import delete
-from .subparsers import dependencies
+from .subparsers import dependents
+from .subparsers import deps
 from .subparsers import doc
-from .subparsers import fetch
 from .subparsers import help as help_
 from .subparsers import install
+from .subparsers import list as list_
 from .subparsers import new
 from .subparsers import publish
 from .subparsers import run
@@ -28,18 +29,19 @@ The Mys programming language package manager.
 
 Available subcommands are:
 
-    {cyan('new')}           Create a new package.
-    {cyan('build')}         Build the appliaction.
-    {cyan('run')}           Build and run the application.
-    {cyan('test')}          Build and run tests
-    {cyan('clean')}         Remove build output.
-    {cyan('dependencies')}  Show dependencies.
-    {cyan('publish')}       Publish a release to the registry.
-    {cyan('delete')}        Delete a package from the registry.
-    {cyan('install')}       Install an application from local package or registry.
-    {cyan('doc')}           Build the documentation.
-    {cyan('fetch')}         Download and extract all dependencies.
-    {cyan('style')}         Code styling.
+    {cyan('new')}         Create a new package.
+    {cyan('build')}       Build the appliaction.
+    {cyan('run')}         Build and run the application.
+    {cyan('test')}        Build and run tests
+    {cyan('clean')}       Remove build output.
+    {cyan('doc')}         Build the documentation.
+    {cyan('style')}       Code styling.
+    {cyan('publish')}     Publish a release to the registry.
+    {cyan('delete')}      Delete a package from the registry.
+    {cyan('install')}     Install an application from local package or registry.
+    {cyan('list')}        Show packages in registry.
+    {cyan('deps')}        Show dependencies.
+    {cyan('dependents')}  Show dependents.
 '''
 
 
@@ -98,14 +100,15 @@ def create_parser():
     run.add_subparser(subparsers)
     test.add_subparser(subparsers)
     clean.add_subparser(subparsers)
-    transpile.add_subparser(subparsers)
-    dependencies.add_subparser(subparsers)
+    style.add_subparser(subparsers)
+    doc.add_subparser(subparsers)
     publish.add_subparser(subparsers)
     delete.add_subparser(subparsers)
     install.add_subparser(subparsers)
-    style.add_subparser(subparsers)
-    doc.add_subparser(subparsers)
-    fetch.add_subparser(subparsers)
+    list_.add_subparser(subparsers)
+    deps.add_subparser(subparsers)
+    dependents.add_subparser(subparsers)
+    transpile.add_subparser(subparsers)
     help_.add_subparser(subparsers)
 
     return parser
