@@ -9,6 +9,7 @@ from ..utils import BULB
 from ..utils import BuildConfig
 from ..utils import add_coverage_argument
 from ..utils import add_debug_symbols_argument
+from ..utils import add_download_argument
 from ..utils import add_jobs_argument
 from ..utils import add_no_ccache_argument
 from ..utils import add_optimize_argument
@@ -45,15 +46,18 @@ def do_run(_parser, args, _mys_config):
                                args.coverage,
                                args.unsafe,
                                args.jobs,
-                               args.url)
+                               args.url,
+                               args.download)
     is_application, build_dir, _ = build_prepare(build_config)
 
     if is_application:
         build_app(build_config, True, build_dir)
-        run_app(args.args, args.verbose, build_dir)
 
-        if args.coverage:
-            create_coverage_report()
+        try:
+            run_app(args.args, args.verbose, build_dir)
+        finally:
+            if args.coverage:
+                create_coverage_report()
     else:
         main_1 = style_source('def main():\n')
         main_2 = style_source("    print('Hello, world!')\n")
@@ -78,6 +82,7 @@ def add_subparser(subparsers):
     add_debug_symbols_argument(subparser)
     add_no_ccache_argument(subparser)
     add_url_argument(subparser)
+    add_download_argument(subparser)
     add_coverage_argument(subparser)
     add_unsafe_argument(subparser)
     subparser.add_argument('args', nargs='*')
