@@ -3,6 +3,7 @@ import os
 from ..run import run
 from ..utils import BuildConfig
 from ..utils import add_coverage_argument
+from ..utils import add_download_argument
 from ..utils import add_jobs_argument
 from ..utils import add_no_ccache_argument
 from ..utils import add_optimize_argument
@@ -22,7 +23,8 @@ def do_test(_parser, args, _mys_config):
                                args.coverage,
                                args.unsafe,
                                args.jobs,
-                               args.url)
+                               args.url,
+                               args.download)
     _, build_dir, _ = build_prepare(build_config)
 
     command = [
@@ -49,11 +51,18 @@ def do_test(_parser, args, _mys_config):
     else:
         test_pattern = [args.test_pattern]
 
-    run(command, 'Building tests', args.verbose)
-    run([f'./{build_dir}/test'] + test_pattern, 'Running tests', args.verbose)
+    status_path = f'{build_dir}/status.txt'
+    run(command, 'Building tests', args.verbose, status_path=status_path)
 
-    if args.coverage:
-        create_coverage_report(['./src/**'])
+    try:
+        run([f'./{build_dir}/test', '-s', status_path] + test_pattern,
+            'Running tests',
+            args.verbose,
+            status_path=status_path,
+            message_as_final=False)
+    finally:
+        if args.coverage:
+            create_coverage_report(['./src/**'])
 
 
 def add_subparser(subparsers):
@@ -65,6 +74,7 @@ def add_subparser(subparsers):
     add_optimize_argument(subparser, 'debug')
     add_no_ccache_argument(subparser)
     add_url_argument(subparser)
+    add_download_argument(subparser)
     add_coverage_argument(subparser)
     add_unsafe_argument(subparser)
     subparser.add_argument(
