@@ -1,6 +1,7 @@
 import glob
 import multiprocessing
 import os
+import platform
 import shutil
 import sys
 
@@ -45,6 +46,15 @@ COPY_ASSET_FMT = '''\
 '''
 
 
+def system():
+    value = platform.system()
+
+    if value.startswith('CYGWIN'):
+        value = 'Cygwin'
+
+    return value
+
+
 class BuildConfig:
 
     def __init__(self,
@@ -56,7 +66,8 @@ class BuildConfig:
                  coverage,
                  unsafe,
                  jobs,
-                 url):
+                 url,
+                 download):
         self.debug = debug
         self.verbose = verbose
         self.optimize = optimize
@@ -66,6 +77,7 @@ class BuildConfig:
         self.unsafe = unsafe
         self.jobs = jobs
         self.url = url
+        self.download = download
 
 
 def create_file(path, data):
@@ -107,7 +119,10 @@ def create_file_from_template(path, directory, **kwargs):
     create_file_from_template_path(path, os.path.join(directory, path), **kwargs)
 
 
-def setup_build():
+def setup_build(download):
+    if download:
+        shutil.rmtree(DOWNLOAD_DIRECTORY, ignore_errors=True)
+
     os.makedirs(DOWNLOAD_DIRECTORY, exist_ok=True)
 
 
@@ -335,6 +350,7 @@ def create_makefile(config, dependencies_configs, build_config):
         f'{build_dir}/Makefile',
         'build/Makefile',
         build=build_dir,
+        status_path=f'{build_dir}/status.txt',
         mys_dir=MYS_DIR,
         mys=f'{sys.executable} -m mys',
         ccache=ccache,
@@ -343,6 +359,7 @@ def create_makefile(config, dependencies_configs, build_config):
         transpile_options=' '.join(transpile_options),
         transpile_srcs_paths=' '.join(transpile_srcs_paths),
         transpile_srcs=' '.join(transpile_srcs),
+        number_of_modules=len(srcs_mys),
         hpps=' '.join(hpps),
         copy_hpp_and_cpp='\n'.join(copy_hpp_and_cpp),
         copy_assets='\n'.join(copy_assets),
@@ -351,20 +368,29 @@ def create_makefile(config, dependencies_configs, build_config):
         package_name=config.name,
         transpiled_cpp='\n'.join(transpiled_cpp),
         cflags=cflags,
-        libs=libs)
+        libs=libs,
+        system=system())
 
     return is_application, build_dir
 
 
+def create_feature_cpp(build_dir):
+    with open(f'{build_dir}/feature.cpp', 'w') as fout:
+        fout.write('int main() { return 0; }')
+
+
 def build_prepare(build_config, config=None):
     if config is None:
         config = read_package_configuration()
 
-    setup_build()
-    dependencies_configs = download_dependencies(config, build_config.url)
+    setup_build(build_config.download)
+    dependencies_configs = download_dependencies(config,
+                                                 build_config.url,
+                                                 build_config.download)
     is_application, build_dir = create_makefile(config,
                                                 dependencies_configs,
                                                 build_config)
+    create_feature_cpp(build_dir)
 
     return is_application, build_dir, dependencies_configs
 
@@ -393,7 +419,10 @@ def build_app(build_config, is_application, build_dir):
     if build_config.optimize == 'debug':
         command += ['TRACEBACK=yes']
 
-    run(command, 'Building', build_config.verbose)
+    run(command,
+        'Building',
+        build_config.verbose,
+        status_path=f'{build_dir}/status.txt')
 
 
 def add_verbose_argument(subparser):
@@ -436,6 +465,12 @@ def add_url_argument(subparser):
                            help='Website URL (default: %(default)s).')
 
 
+def add_download_argument(subparser):
+    subparser.add_argument('-d', '--download',
+                           action='store_true',
+                           help='Force download of dependencies from the website.')
+
+
 def add_coverage_argument(subparser):
     subparser.add_argument(
         '-c', '--coverage',
