@@ -61,9 +61,7 @@ def data_filename(fname, pkgdir=""):
             else:
                 tried.append(static_filename)
     raise CoverageException(
-        "Couldn't find static file %r from %r, tried: %r" % (fname, os.getcwd(),
-                                                             tried)
-    )
+        f"Couldn't find static file {fname} from {os.getcwd()}, tried: {tried}")
 
 
 def read_data(fname):
@@ -122,7 +120,7 @@ class HtmlDataGeneration:
                 if contexts == [self.EMPTY]:
                     contexts_label = self.EMPTY
                 else:
-                    contexts_label = "{} ctx".format(len(contexts))
+                    contexts_label = f"{len(contexts)} ctx"
                     context_list = contexts
 
             lines.append(SimpleNamespace(
@@ -302,16 +300,14 @@ class HtmlReporter:
                     html.append(escape(tok_text))
                 else:
                     tok_html = escape(tok_text) or '&nbsp;'
-                    html.append(
-                        u'<span class="{}">{}</span>'.format(tok_type, tok_html)
-                    )
+                    html.append(f'<span class="{tok_type}">{tok_html}</span>')
             ldata.html = ''.join(html)
 
             if ldata.short_annotations:
                 # 202F is NARROW NO-BREAK SPACE.
                 # 219B is RIGHTWARDS ARROW WITH STROKE.
-                ldata.annotate = u",&nbsp;&nbsp; ".join(
-                    u"{}&#x202F;&#x219B;&#x202F;{}".format(ldata.number, d)
+                ldata.annotate = ",&nbsp;&nbsp; ".join(
+                    f"{ldata.number}&#x202F;&#x219B;&#x202F;{d}"
                     for d in ldata.short_annotations
                     )
             else:
@@ -322,13 +318,11 @@ class HtmlReporter:
                 if len(longs) == 1:
                     ldata.annotate_long = longs[0]
                 else:
-                    ldata.annotate_long = u"{:d} missed branches: {}".format(
-                        len(longs),
-                        u", ".join(
-                            u"{:d}) {}".format(num, ann_long)
-                            for num, ann_long in enumerate(longs, start=1)
-                            ),
-                    )
+                    missed_branches = ", ".join(
+                        f"{num:d}) {ann_long}"
+                        for num, ann_long in enumerate(longs, start=1))
+                    ldata.annotate_long = (
+                        f"{len(longs):d} missed branches: {missed_branches}")
             else:
                 ldata.annotate_long = None
 
@@ -512,4 +506,4 @@ def escape(tt):
 
 def pair(ratio):
     """Format a pair of numbers so JavaScript can read them in an attribute."""
-    return "%s %s" % ratio
+    return f"{ratio[0]} {ratio[1]}"
