@@ -1,5 +1,6 @@
 #include <iomanip>
 #include <alloca.h>
+#include <getopt.h>
 #include "mys.hpp"
 
 #include "unicodectype.cpp"
@@ -9,7 +10,7 @@
 
 extern void __application_init(void);
 extern void __application_exit(void);
-extern void package_main(int argc, const char *argv[]);
+extern void package_main(int argc, char * const argv[]);
 
 #if defined(MYS_TEST)
 #    include <chrono>
@@ -94,7 +95,7 @@ void print_error_traceback(const mys::shared_ptr<Error>& error,
 
 #endif
 
-mys::shared_ptr<List<String>> create_args(int argc, const char *argv[])
+mys::shared_ptr<List<String>> create_args(int argc, char * const argv[])
 {
     int i;
     auto args = mys::make_shared<List<String>>();
@@ -169,7 +170,7 @@ operator<<(std::ostream& os, const Bytes& obj)
 }
 
 #if defined(MYS_COVERAGE)
-std::ofstream mys_coverage_file;
+std::ofstream mys_coverage_file(".mys-coverage.txt");
 #endif
 
 #if defined(MYS_TEST)
@@ -211,6 +212,18 @@ Test::Test(const char *name_p, test_func_t func)
 
 using namespace std::chrono;
 
+static int count_tests(Test *test_p)
+{
+    int total = 0;
+
+    while (test_p != NULL) {
+        total++;
+        test_p = test_p->m_next_p;
+    }
+
+    return total;
+}
+
 static bool is_test_match(Test *test_p, const char *test_pattern_p)
 {
     const char *full_test_name_p;
@@ -279,18 +292,136 @@ static bool is_test_match(Test *test_p, const char *test_pattern_p)
     return true;
 }
 
-int main(int argc, const char *argv[])
+static void print_usage_and_exit(const char *program_name_p, int exit_code)
+{
+    printf("usage: %s [-h] [-s] [<test-pattern>]\n"
+           "\n"
+           "Run tests.\n"
+           "\n"
+           "positional arguments:\n"
+           "  test-pattern                  Only run tests matching given pattern. "
+           "'^' matches\n"
+           "                                the beginning and '$' matches the end "
+           "of the test\n"
+           "                                name.\n"
+           "\n"
+           "optional arguments:\n"
+           "  -h, --help                    Show this help message and exit.\n"
+           "  -s, --status-path             Status file path.\n",
+           program_name_p);
+    exit(exit_code);
+}
+
+static void parse_args(int argc,
+                       char * const argv[],
+                       const char **status_path_pp,
+                       const char **test_pattern_pp)
+{
+    static struct option long_options[] = {
+        { "help",        no_argument,       NULL, 'h' },
+        { "status-path", required_argument, NULL, 's' },
+        { NULL,          no_argument,       NULL, 0 }
+    };
+    int option;
+
+    *status_path_pp = NULL;
+    *test_pattern_pp = NULL;
+
+    while (1) {
+        option = getopt_long(argc, argv, "hs:", &long_options[0], NULL);
+
+        if (option == -1) {
+            break;
+        }
+
+        switch (option) {
+
+        case 'h':
+            print_usage_and_exit(argv[0], 0);
+            break;
+
+        case 's':
+            *status_path_pp = optarg;
+            break;
+
+        default:
+            print_usage_and_exit(argv[0], 1);
+            break;
+        }
+    }
+
+    if (optind < argc) {
+        *test_pattern_pp = argv[optind];
+    }
+}
+
+static void print_status_message(std::shared_ptr<std::fstream> &status,
+                                 char kind,
+                                 Test *test_p,
+                                 int test,
+                                 int total)
+{
+    if (status) {
+        *status
+            << kind
+            << " Running test "
+            << test
+            << "/"
+            << total
+            << ": "
+            << test_p->m_name_p
+            << std::endl;
+    }
+}
+
+static void print_summary(int passed, int failed, int skipped, int total)
+{
+    std::cout << "\nTests: ";
+
+    if (passed > 0) {
+        std::cout
+            << ANSI_RESET ANSI_COLOR_GREEN ANSI_BOLD
+            << passed
+            << " passed"
+            << ANSI_RESET
+            << ", ";
+    }
+
+    if (failed > 0) {
+        std::cout
+            << ANSI_RESET ANSI_COLOR_RED ANSI_BOLD
+            << failed
+            << " failed"
+            << ANSI_RESET
+            << ", ";
+    }
+
+    if (skipped > 0) {
+        std::cout
+            << ANSI_RESET ANSI_COLOR_YELLOW ANSI_BOLD
+            << skipped
+            << "skipped"
+            << ANSI_RESET
+            << ", ";
+    }
+
+    std::cout << total << " total\n";
+}
+
+int main(int argc, char * const argv[])
 {
     Test *test_p;
+    int passed = 0;
     int failed = 0;
+    int skipped = 0;
     const char *result_p;
     const char *test_pattern_p;
+    const char *status_path_p;
 
-    if (argc == 2) {
-        test_pattern_p = argv[1];
-    } else {
-        test_pattern_p = NULL;
-    }
+    parse_args(argc,
+               argv,
+               &status_path_p,
+               &test_pattern_p);
 
     ignore_sigpipe();
 
@@ -308,15 +439,26 @@ int main(int argc, const char *argv[])
         return 1;
     }
 
+    std::shared_ptr<std::fstream> status;
+
+    if (status_path_p != NULL) {
+        status = std::make_shared<std::fstream>(status_path_p, std::fstream::out);
+    }
+
+    int total = count_tests(tests_head_p);
     test_p = tests_head_p;
+    int test = 1;
 
     while (test_p != NULL) {
         if (is_test_match(test_p, test_pattern_p)) {
+            print_status_message(status, '>', test_p, test, total);
+
             auto begin = steady_clock::now();
 
             try {
                 test_p->m_func();
                 result_p = COLOR(GREEN, " ✔");
+                passed++;
             } catch (const __Error &e) {
                 __MYS_TRACEBACK_RESTORE();
                 print_error_traceback(e.m_error, std::cout);
@@ -333,11 +475,27 @@ int main(int argc, const char *argv[])
                 << " " << test_p->m_name_p
                 << " (" <<  duration << " ms)"
                 << std::endl;
+
+            print_status_message(status, '<', test_p, test, total);
+        } else {
+            skipped++;
         }
 
+        test++;
         test_p = test_p->m_next_p;
     }
 
+    print_summary(passed, failed, skipped, total);
+
+    if (status != nullptr) {
+        *status
+            << "> Running "
+            << total
+            << " test"
+            << (total == 1 ? "" : "s")
+            << std::endl;
+    }
+
     try {
         __application_exit();
     } catch (const __Error &e) {
@@ -360,7 +518,7 @@ int main(int argc, const char *argv[])
 
 #elif defined(MYS_APPLICATION)
 
-int main(int argc, const char *argv[])
+int main(int argc, char * const argv[])
 {
     int res = 1;
 
@@ -541,7 +699,7 @@ const RegexMatch& regexmatch_not_none(const RegexMatch& obj)
     return obj;
 }
 
-const Bytes& bytes_not_none(const Bytes& obj)
+Bytes bytes_not_none(Bytes obj)
 {
     if (!obj.m_bytes) {
         abort_is_none();
@@ -630,25 +788,6 @@ String::String(const Bytes& bytes, i64 begin, i64 end)
     }
 }
 
-#if 0
-Bytes String::to_utf8() const
-{
-    Bytes res({});
-    size_t size;
-    char buf[4];
-
-    for (const auto & ch : *m_string) {
-        size = encode_utf8(&buf[0], ch.m_value);
-
-        for (size_t i = 0; i < size; i++) {
-            res += buf[i];
-        }
-    }
-
-    return res;
-}
-#endif
-
 String String::operator+(const String& other)
 {
     String res("");
@@ -992,26 +1131,6 @@ Char& String::get(i64 index) const
 
 #endif
 
-u8& Bytes::operator[](i64 index) const
-{
-    if (index < 0) {
-        index = m_bytes->size() + index;
-    }
-
-#if !defined(MYS_UNSAFE)
-    if (index < 0 || index >= static_cast<i64>(m_bytes->size())) {
-        print_traceback();
-        std::cerr
-            << "\nPanic(message=\"Bytes index "
-            << index
-            << " is out of range.\")\n";
-        abort();
-    }
-#endif
-
-    return (*m_bytes)[index];
-}
-
 i64 String::__int__() const
 {
     return __int__(10);
@@ -1154,6 +1273,16 @@ f64 String::__float__() const
     return value;
 }
 
+String String::__copy__() const
+{
+    return *this;
+}
+
+String String::__deepcopy__() const
+{
+    return *this;
+}
+
 String input(String prompt)
 {
     std::string value;
@@ -1233,30 +1362,31 @@ i64 String::find(const String& sub, std::optional<i64> _begin, std::optional<i64
     }
 
     if (reverse) {
-        auto i_rbegin = m_string->rbegin() + size - end;
-        auto i_rend = m_string->rbegin() + size - begin;
+        auto it_begin = m_string->rbegin() + (size - end);
+        auto it_end = m_string->rbegin() + (size - begin);
+        auto it_match = std::search(it_begin,
+                                    it_end,
+                                    sub.m_string->rbegin(),
+                                    sub.m_string->rend());
 
-        auto s = std::search(
-            i_rbegin,
-            i_rend,
-            sub.m_string->begin(), sub.m_string->end());
-        if (s == i_rend) {
+        if (it_match == it_end) {
             return -1;
         }
-        return s - i_rbegin + end - 1;
-    }
-    else {
-        auto i_begin = m_string->begin() + begin;
-        auto i_end = m_string->begin() + end;
 
-        auto s = std::search(
-            i_begin,
-            i_end,
-            sub.m_string->begin(), sub.m_string->end());
-        if (s == i_end) {
+        return it_end - it_match - sub.m_string->size() + begin;
+    } else {
+        auto it_begin = m_string->begin() + begin;
+        auto it_end = m_string->begin() + end;
+        auto it_match = std::search(it_begin,
+                                    it_end,
+                                    sub.m_string->begin(),
+                                    sub.m_string->end());
+
+        if (it_match == it_end) {
             return -1;
         }
-        return s - i_begin + begin;
+
+        return it_match - it_begin + begin;
     }
 }
 
@@ -1639,6 +1769,16 @@ String Object::__str__()
     return String("Object()");
 }
 
+bool Object::__eq__(const mys::shared_ptr<Object>& other)
+{
+    return false;
+}
+
+i64 Object::__hash__()
+{
+    return 0;
+}
+
 void AssertionError::__throw()
 {
     throw __AssertionError(mys::shared_ptr<AssertionError>(this));
@@ -2115,6 +2255,129 @@ i64 Bytes::find(const Bytes& needle,
     return s - i_begin + begin;
 }
 
+Bytes Bytes::get(std::optional<i64> _begin, std::optional<i64> _end,
+                 i64 step) const
+{
+    int size = m_bytes->size();
+    int begin;
+    int end;
+
+    if (step > 0) {
+        begin = _begin.value_or(0);
+        end = _end.value_or(size);
+    }
+    else {
+        begin = _begin.value_or(size - 1);
+        end = _end.value_or(-size - 1);
+    }
+
+    if (begin < 0) {
+        begin = m_bytes->size() + begin;
+        if (begin < 0) {
+            begin = (step < 0) ? -1 : 0;
+        }
+    }
+    else if (begin >= size) {
+        begin = (step < 0) ? size - 1 : size;
+    }
+
+    if (end < 0) {
+        end = m_bytes->size() + end;
+        if (end < 0) {
+            end = (step < 0) ? -1 : 0;
+        }
+    }
+    else if (end >= size) {
+        end = (step < 0) ? size - 1 : size;
+    }
+
+    Bytes res(static_cast<u64>(0));
+    int i = begin;
+
+    if (step == 1) {
+        res.m_bytes->resize(end - begin);
+        std::copy(m_bytes->begin() + begin,
+                  m_bytes->begin() + end,
+                  res.m_bytes->begin());
+    } else if (step > 0) {
+        while (i < end) {
+            res += (*m_bytes)[i];
+            i += step;
+        }
+    } else {
+        while (i > end) {
+            res += (*m_bytes)[i];
+            i += step;
+        }
+    }
+
+    return res;
+}
+
+#if !defined(MYS_UNSAFE)
+
+u8& Bytes::get(i64 index) const
+{
+    if (index < 0) {
+        index = m_bytes->size() + index;
+    }
+
+    if (index < 0 || index >= static_cast<i64>(m_bytes->size())) {
+        print_traceback();
+        std::cerr
+            << "\nPanic(message=\"Bytes index "
+            << index
+            << " is out of range.\")\n";
+        abort();
+    }
+
+    return (*m_bytes)[index];
+}
+
+#endif
+
+Bool Bytes::starts_with(const Bytes& value) const
+{
+    int value_length = value.__len__();
+
+    if (value_length > m_bytes->size()) {
+        return false;
+    }
+
+    for (u64 i = 0; i < value_length; i++) {
+        if ((*m_bytes)[i] != (*value.m_bytes)[i]) {
+            return false;
+        }
+    }
+
+    return true;
+}
+
+Bool Bytes::ends_with(const Bytes& value) const
+{
+    int value_length = value.__len__();
+    int begin = m_bytes->size() - value_length;
+
+    if (begin < 0) {
+        return false;
+    }
+
+    for (u64 i = 0; i < value_length; i++) {
+        if ((*m_bytes)[begin + i] != (*value.m_bytes)[i]) {
+            return false;
+        }
+    }
+
+    return true;
+}
+
+void Bytes::copy_into(const Bytes& data, i64 start, i64 end, i64 to_start)
+{
+    std::copy(data.m_bytes->begin() + start,
+              data.m_bytes->begin() + end,
+              m_bytes->begin() + to_start);
+}
+
 Error::Error()
 {
 #if defined(MYS_TRACEBACK)
@@ -2161,7 +2424,7 @@ String assets(const char *package_p)
 
 #if defined(MYS_APPLICATION) || defined(MYS_TEST)
 
-int main(int argc, const char *argv[])
+int main(int argc, char * const argv[])
 {
     return mys::main(argc, argv);
 }
