@@ -107,7 +107,11 @@ class MysLexer(RegexLexer):
             (r'\\', Text),
             include('keywords'),
             (r'(def)((?:\s|\\\s)+)', bygroups(Keyword, Text), 'funcname'),
+            (r'(func)((?:\s|\\\s)+)', bygroups(Keyword, Text), 'funcname'),
+            (r'(test)((?:\s|\\\s)+)', bygroups(Keyword, Text), 'funcname'),
             (r'(class)((?:\s|\\\s)+)', bygroups(Keyword, Text), 'classname'),
+            (r'(enum)((?:\s|\\\s)+)', bygroups(Keyword, Text), 'classname'),
+            (r'(trait)((?:\s|\\\s)+)', bygroups(Keyword, Text), 'classname'),
             (r'(from)((?:\s|\\\s)+)', bygroups(Keyword.Namespace, Text),
              'fromimport'),
             (r'(import)((?:\s|\\\s)+)', bygroups(Keyword.Namespace, Text),
