@@ -74,7 +74,7 @@ class Traceback:
 
 class Context:
     """The context keeps track of defined functions, classes, traits,
-    enums and variables in the current scope. Ot also provides other
+    enums and variables in the current scope. It also provides other
     services, like unique numbers and full name convertions.
 
     """
@@ -328,11 +328,9 @@ class Context:
     def pop(self):
         result = {}
 
-        for name in self._stack[-1]:
+        for name in self._stack.pop():
             result[name] = self.local_variables.pop(name)
 
-        self._stack.pop()
-
         return State(result, self._raises.pop(), self._returns.pop())
 
     def set_always_raises(self, value):
