@@ -43,14 +43,20 @@ class TypeVisitor(ast.NodeVisitor):
         return {self.visit(node.elts[0])}
 
     def visit_Subscript(self, node):
-        types = self.visit(node.slice)
+        value = self.visit(node.value)
 
-        if isinstance(node.slice, ast.Name):
-            types = [types]
+        if value == 'lazy':
+            # Not lazy right now.
+            return self.visit(node.slice)
         else:
-            types = list(types)
+            types = self.visit(node.slice)
 
-        return GenericType(self.visit(node.value), types, node)
+            if isinstance(node.slice, ast.Name):
+                types = [types]
+            else:
+                types = list(types)
+
+            return GenericType(value, types, node)
 
 
 class FormatDefaultVisitor(ast.NodeVisitor):
