@@ -166,11 +166,7 @@ class SourceVisitor(ast.NodeVisitor):
         ]
 
     def add_application_exit(self, ordered_modules):
-        body = [
-            '#if defined(MYS_COVERAGE)',
-            '    mys::mys_coverage_file.open(".mys-coverage.txt");',
-            '#endif'
-        ]
+        body = []
 
         for module in ordered_modules:
             self.before_namespace += [
@@ -301,7 +297,7 @@ class SourceVisitor(ast.NodeVisitor):
     def main(self):
         if self.add_package_main:
             return [
-                'void package_main(int argc, const char *argv[])',
+                'void package_main(int argc, char * const argv[])',
                 '{',
                 f'    {self.namespace}::main(argc, argv);',
                 '}'
@@ -463,7 +459,10 @@ class SourceVisitor(ast.NodeVisitor):
                     f'{return_cpp_type} {class_name}::{method_name}({parameters})')
 
             body.append('{')
-            body.append(self.context.traceback.enter(method.name))
+
+            if method.name != '__del__':
+                body.append(self.context.traceback.enter(method.name))
+
             body_iter = iter(method.node.body)
 
             if has_docstring(method.node):
@@ -471,12 +470,17 @@ class SourceVisitor(ast.NodeVisitor):
 
             for item in body_iter:
                 BodyCheckVisitor().visit(item)
-                body.append(self.context.traceback.set(item.lineno))
+
+                if method.name != '__del__':
+                    body.append(self.context.traceback.set(item.lineno))
+
                 body.append(indent(BodyVisitor(self.context,
                                                self.filename,
                                                self.version).visit(item)))
 
-            body.append(self.context.traceback.exit())
+            if method.name != '__del__':
+                body.append(self.context.traceback.exit())
+
             body.append('}')
             self.context.pop()
 
@@ -542,7 +546,7 @@ class SourceVisitor(ast.NodeVisitor):
         else:
             body = ['    auto argv = create_args(__argc, __argv);'] + body
 
-        parameters = 'int __argc, const char *__argv[]'
+        parameters = 'int __argc, char * const __argv[]'
 
         return body, parameters
 
