@@ -95,6 +95,11 @@ BUILTIN_CALLS = set(
         'zip',
         'string',
         'default',
+        'any',
+        'all',
+        'hash',
+        'copy',
+        'deepcopy',
         '__MYS_TRACEBACK_ENTER',
         '__MYS_TRACEBACK_EXIT',
         '__MYS_TRACEBACK_SET'
@@ -196,7 +201,12 @@ STRING_METHODS = {
 
 BYTES_METHODS = {
     'to_hex': [[], 'string'],
-    'find': [['string', 'optional<i64>', 'optional<i64>'], 'i64']
+    'find': [['string', 'optional<i64>', 'optional<i64>'], 'i64'],
+    'reserve': [['i64'], None],
+    'resize': [['i64'], None],
+    'starts_with': [['bytes'], 'bool'],
+    'ends_with': [['bytes'], 'bool'],
+    'copy_into': [['bytes', 'i64', 'i64', 'i64'], None]
 }
 
 LIST_METHODS = {
@@ -208,7 +218,8 @@ LIST_METHODS = {
     'sort': [[], None],
     'count': [['<listtype>'], 'i64'],
     'pop': [['i64'], '<listtype>'],
-    'clear': [[], None]
+    'clear': [[], None],
+    'find': [['<listtype>'], 'i64']
 }
 
 REGEX_METHODS = {
