@@ -224,7 +224,7 @@ def reduce_type(value_type):
     elif value_type is None:
         return None
     else:
-        raise Exception("Bad reduce")
+        raise Exception(f"Bad reduce of value type {value_type}.")
 
 
 class Set:
@@ -318,7 +318,12 @@ class ValueTypeVisitor(ast.NodeVisitor):
             else:
                 value_type = 'char'
         elif value_type == 'bytes':
-            value_type = 'u8'
+            slice_type = self.visit(node.slice)
+
+            if isinstance(slice_type, tuple):
+                value_type = 'bytes'
+            else:
+                value_type = 'u8'
         else:
             raise Exception('todo')
 
@@ -641,13 +646,13 @@ class ValueTypeVisitor(ast.NodeVisitor):
             return [('i64', self.visit(node.args[0]))]
         elif name == 'zip':
             # ???
-            return [self.visit(node.args[0])]
+            return self.visit(node.args[0])
         elif name == 'slice':
             # ???
-            return [self.visit(node.args[0])]
+            return self.visit(node.args[0])
         elif name == 'reversed':
             # ???
-            return [self.visit(node.args[0])]
+            return self.visit(node.args[0])
         elif name == 'input':
             return 'string'
         elif name in BUILTIN_ERRORS:
@@ -661,6 +666,12 @@ class ValueTypeVisitor(ast.NodeVisitor):
                 return self.context.make_full_name(type_name)
             else:
                 return type_name
+        elif name in ['any', 'all']:
+            return 'bool'
+        elif name == 'hash':
+            return 'i64'
+        elif name in ['copy', 'deepcopy']:
+            return self.visit(node.args[0])
         else:
             raise InternalError(f"builtin '{name}' not supported", node)
 
