@@ -91,42 +91,6 @@ class Test(TestCase):
 
             self.assert_file_exists('./build/speed/app')
 
-            # Run again, but with run() mock to verify that the
-            # application is run.
-            run_result = Mock()
-            run_mock = Mock(side_effect=run_result)
-
-            with patch('subprocess.run', run_mock):
-                with patch('sys.argv', ['mys', 'run', '-j', '1']):
-                    mys.cli.main()
-
-            # -j 1 is not passed to make if a jobserver is already
-            # running.
-            self.assertIn(
-                run_mock.mock_calls,
-                [
-                    [
-                        call(['make', '-f', 'build/speed/Makefile', 'all',
-                              '-s', 'APPLICATION=yes'],
-                             stdout=subprocess.PIPE,
-                             stderr=subprocess.STDOUT,
-                             encoding='utf-8',
-                             close_fds=False,
-                             env=None),
-                        call(['./build/speed/app'], check=True)
-                    ],
-                    [
-                        call(['make', '-f', 'build/speed/Makefile', 'all',
-                              '-j', '1', '-s', 'APPLICATION=yes'],
-                             stdout=subprocess.PIPE,
-                             stderr=subprocess.STDOUT,
-                             encoding='utf-8',
-                             close_fds=False,
-                             env=None),
-                        call(['./build/speed/app'], check=True)
-                    ]
-                ])
-
             # Test.
             with patch('sys.argv', ['mys', '-d', 'test', '-j', '1']):
                 mys.cli.main()
@@ -383,17 +347,17 @@ class Test(TestCase):
         path = os.getcwd()
 
         with Path(f'tests/build/{package_name}'):
-            _, stderr = run_mys_command(['build', '-v'], path)
+            _, stderr = run_mys_command(['build'], path)
 
             self.assertNotIn('jobserver unavailable', stderr)
 
         with Path(f'tests/build/{package_name}'):
-            _, stderr = run_mys_command(['run', '-v'], path)
+            _, stderr = run_mys_command(['run'], path)
 
             self.assertNotIn('jobserver unavailable', stderr)
 
         with Path(f'tests/build/{package_name}'):
-            _, stderr = run_mys_command(['test', '-v'], path)
+            _, stderr = run_mys_command(['test'], path)
 
             self.assertNotIn('jobserver unavailable', stderr)
 
@@ -436,7 +400,7 @@ class Test(TestCase):
             stdout = StringIO()
 
             with patch('sys.stdout', stdout):
-                with patch('sys.argv', ['mys', 'dependencies']):
+                with patch('sys.argv', ['mys', 'deps']):
                     mys.cli.main()
 
             self.assert_in('dep1 = { path = "../dep1" }\n'
@@ -448,7 +412,7 @@ class Test(TestCase):
             stdout = StringIO()
 
             with patch('sys.stdout', stdout):
-                with patch('sys.argv', ['mys', 'dependencies', '--versions']):
+                with patch('sys.argv', ['mys', 'deps', '--versions']):
                     mys.cli.main()
 
             self.assert_in('dep1 = "1.1.0"\n'
